import { ComponentRef, NgModuleRef } from '@angular/core';
import { LazyDialogContainerComponent } from '../components';
/**
 * The reference of a lazy dialog.
 *
 * @export
 * @class LazyDialogRef
 * @typedef {LazyDialogRef}
 * @template DataType
 */
export declare class LazyDialogRef<DataType> {
    /**
     * The data passed to the lazy dialog.
     *
     * @public
     * @readonly
     * @type {?DataType}
     */
    readonly data?: DataType;
    /**
     * Represents the close event stream being called when {@link close} function is called.
     *
     * @private
     * @readonly
     * @type {Subject<any>}
     */
    private readonly close$;
    /**
     * The reference of the dialog component's container component.
     *
     * @private
     * @type {ComponentRef<LazyDialogContainerComponent>}
     */
    private containerComponentRef;
    /**
     * The module reference of the dialog component (optional: {@link https://angular.io/guide/standalone-components standalone components} aren't related to a {@link https://angular.io/api/core/NgModule NgModule}).
     *
     * @private
     * @type {?NgModuleRef<unknown>}
     */
    private moduleRef?;
    /**
     * Creates an instance of LazyDialogRef.
     *
     * @constructor
     * @public
     * @param {ComponentRef<LazyDialogContainerComponent>} containerComponentRef The reference of the dialog component's container component.
     * @param {?NgModuleRef<unknown>} [moduleRef] The module reference of the dialog component (optional: {@link https://angular.io/guide/standalone-components standalone components} aren't related to a {@link https://angular.io/api/core/NgModule NgModule}).
     * @param {?DataType} [data] The data of the lazy dialog.
     */
    constructor(containerComponentRef: ComponentRef<LazyDialogContainerComponent>, moduleRef?: NgModuleRef<unknown>, data?: DataType);
    /**
     * Triggers the dialog close process as well as informing {@link onClose} with the provided {@link output} via {@link https://rxjs.dev/guide/subject Subject<any>} close$.
     *
     * @public
     * @param {?*} [output]
     */
    close(output?: any): void;
    /**
     * Informs the consumer with the provided data about the dialog close event.
     *
     * @public
     * @async
     * @returns {Promise<any>}
     */
    onClose(): Promise<any>;
    /**
     * Destroys the dialog container, module reference and close$ stream.
     *
     * @private
     */
    private destroy;
}
